@@ -129,11 +129,7 @@ int gps_dbus_open(struct gps_data_t *gpsdata)
         return 5;
     }
 
-#ifndef USE_QT
-    gpsdata->gps_fd = DBUS_PSEUDO_FD;
-#else
-    gpsdata->gps_fd = (void *)(intptr_t)DBUS_PSEUDO_FD;
-#endif  // USE_QT
+    gpsdata->gps_fd = (gps_fd_t)DBUS_PSEUDO_FD;
     share_gpsdata = gpsdata;
     return 0;
 }
